@@ -16,6 +16,8 @@ describe 'tacker::db::postgresql' do
         required_params
       end
 
+      it { is_expected.to contain_class('tacker::deps') }
+
       it { is_expected.to contain_openstacklib__db__postgresql('tacker').with(
         :user       => 'tacker',
         :password   => 'tackerpass',
@@ -34,7 +36,10 @@ describe 'tacker::db::postgresql' do
         facts.merge!(OSDefaults.get_facts({ :concat_basedir => '/var/lib/puppet/concat' }))
       end
 
-      it_behaves_like 'tacker-db-postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_behaves_like 'tacker-db-postgresql'
+      end
     end
   end
 end
