@@ -24,9 +24,14 @@ describe 'tacker::server' do
     it { is_expected.to contain_class('tacker::policy') }
 
     it 'configures api' do
+      is_expected.to contain_tacker_config('DEFAULT/auth_strategy').with_value('keystone')
       is_expected.to contain_tacker_config('DEFAULT/bind_host').with_value( params[:bind_host] )
       is_expected.to contain_tacker_config('DEFAULT/bind_port').with_value( params[:bind_port] )
       is_expected.to contain_tacker_config('DEFAULT/api_workers').with_value(4)
+      is_expected.to contain_tacker_config('DEFAULT/allow_bulk').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_tacker_config('DEFAULT/allow_pagination').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_tacker_config('DEFAULT/allow_sorting').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_tacker_config('DEFAULT/pagination_max_limit').with_value('<SERVICE DEFAULT>')
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
